@@ -206,10 +206,12 @@ class ROIImageViewModule(ImageViewModule):
             # TODO add in update with image paint layer
             shape = self.main_widget.data_handler.shape
             # range_list = self.main_widget.roi_image_view.image_view.view.viewRange()
-            background_max = self.current_background.max()
-            background_min= self.current_background.min()
-            background_image_scaled = (self.current_foreground_intensity*(self.current_background-background_min) * 235 / (
-                (background_max-background_min) if (background_max-background_min) != 0 else 1))
+            background_max = np.percentile(self.current_background, 98)
+            background_min = np.percentile(self.current_background, 2)
+            background_image_scaled = (self.current_foreground_intensity / 10 * (
+                    self.current_background - background_min) * 235 / (
+                                           (background_max - background_min) if (
+                                                                                        background_max - background_min) != 0 else 1))
             background_image_scaled_3_channel = np.hstack(
                 [background_image_scaled, background_image_scaled,
                  background_image_scaled])
@@ -218,7 +220,7 @@ class ROIImageViewModule(ImageViewModule):
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
                 self.image_item.updateImage(autoLevels=False)
-                self.image_item.ui.histogram.setHistogramRange(0, 255)
+                self.image_item.setLevels((0, 255))
             elif new:
                 # if self.add_image:
                 combined = self.roi_image_flat + background_image_scaled_3_channel + self.select_image_flat
@@ -228,12 +230,14 @@ class ROIImageViewModule(ImageViewModule):
                 #     mask = np.any(self.roi_image_flat != [0, 0, 0], axis=1)
                 #     combined[mask] = self.roi_image_flat[mask]
                 combined_reshaped = combined.reshape((shape[0], shape[1], 3))
+                self.image_item.setLevels((0, 255))
+
                 self.tab.image_view.setImage(combined_reshaped)
             else:
                 self.image_item.image = background_image_scaled_3_channel.reshape(
                     (shape[0], shape[1], 3))
                 self.image_item.updateImage(autoLevels=False)
-                self.image_item.ui.histogram.setHistogramRange(0, 255)
+                self.image_item.setLevels((0, 255))
 
 
                 # if self.add_image:
