@@ -81,7 +81,12 @@ class ROIPaintImageViewModule(ROIImageViewModule):
         new_roi = self.data_handler.genRoiFromPoint((x, y))
         if len(new_roi) == 0:
             print(
-                "Please try again with a bigger growth factor or a different point, we couldn't find an roi where you last selected")
+                "Please try again with a different point, we couldn't find an roi where"
+                " you last selected")
+            self.main_widget.console.updateText("Please try again with a different "
+                                                "point, we couldn't find an roi where "
+                                                "you last selected")
+
             return False
 
         for cord_1d in new_roi:
@@ -92,6 +97,8 @@ class ROIPaintImageViewModule(ROIImageViewModule):
                 shape[1] * x_new + y_new)
             self.current_selected_pixels_mask[x_new, y_new] = True
         self.image_item.updateImage()
+        self.main_widget.console.updateText("Successfully generated selection of size: %s" % str(len(new_roi)))
+
         return True
     def pixel_paint(self, x, y):
         try:
